@@ -8,7 +8,7 @@ class api():
 		res = post('https://coin.world-coin-game.ru/server/api.php', json=data)
 		return res.text
 	def get_url(self, amount=1, code=777, lock=0):
-		return f'vk.com/app7614516#pay_{self.merchant_id}_{amount}_{code}_{lock}'
+		return f'https://vk.com/app7614516#pay_{self.merchant_id}_{amount}_{code}_{lock}'
 	def get_history(self, filter=0, count=5000, offset=0):
 		data = {
     "action": "history",
